@@ -1,4 +1,4 @@
 from .transform import Transform
 from .combinators import sequence, merge, map_tags
-from .workarounds.annot import fileset
+from .workarounds import fileset
 from .context import BakerContext
